@@ -33,6 +33,7 @@ from pyams_auth_ldap.interfaces import ILDAPGroupInfo, ILDAPPlugin, ILDAPUserInf
     INTERNAL_GROUP_MAIL_MODE, NO_GROUP_MAIL_MODE, QUERY_MEMBERS_FROM_GROUP
 from pyams_auth_ldap.query import LDAPQuery
 from pyams_mail.interfaces import IPrincipalMailInfo
+from pyams_security.interfaces.names import PRINCIPAL_ID_FORMATTER
 from pyams_security.principal import PrincipalInfo
 from pyams_utils.adapter import ContextAdapter, adapter_config
 from pyams_utils.factory import factory_config
@@ -55,7 +56,6 @@ USER_ATTR_PREFIX = '{prefix}:{attr}'
 GROUP_DN_PREFIX = '{prefix}:{group_prefix}:{dn}'
 GROUP_ATTR_PREFIX = '{prefix}:{group_prefix}:{attr}'
 
-LOGIN_PREFIX = '{prefix}:{login}'
 GROUP_ID_PREFIX = '{prefix}:{group_prefix}:{group_id}'
 
 
@@ -122,7 +122,7 @@ class LDAPGroupMailInfoAdapter(ContextAdapter):
             # use group internal attribute
             mail = group.attributes.get(plugin.group_mail_attribute)
             if mail:
-                yield plugin.group_title_format(**group.attributes), \
+                yield plugin.group_title_format.format(**group.attributes), \
                       mail[0] if isinstance(mail, (list, tuple)) else mail
 
         else:  # REDIRECT_GROUP_MAIL_MODE
@@ -139,7 +139,7 @@ class LDAPGroupMailInfoAdapter(ContextAdapter):
             target_dn, attrs = result[0]
             mail = attrs.get(plugin.group_mail_attribute)
             if mail:
-                yield plugin.group_title_format(**attrs), \
+                yield plugin.group_title_format.format(**attrs), \
                       mail[0] if isinstance(mail, (list, tuple)) else mail
 
 
@@ -200,6 +200,8 @@ class LDAPPlugin(Persistent, Contained):
     _port = None
     _use_ssl = False
 
+    connection_manager_class = ConnectionManager
+
     _server_uri = FieldProperty(ILDAPPlugin['server_uri'])
     bind_dn = FieldProperty(ILDAPPlugin['bind_dn'])
     bind_password = FieldProperty(ILDAPPlugin['bind_password'])
@@ -293,7 +295,7 @@ class LDAPPlugin(Persistent, Contained):
         """Connection getter"""
         self_id = self._get_id()
         if self_id not in LDAP_MANAGERS:
-            LDAP_MANAGERS[self_id] = ConnectionManager(self)
+            LDAP_MANAGERS[self_id] = self.connection_manager_class(self)
         connection = LDAP_MANAGERS[self_id].get_connection(user, password)
         if connection.closed:
             connection.open(read_server_info=False)
@@ -330,7 +332,7 @@ class LDAPPlugin(Persistent, Contained):
                                                attr=attrs[self.uid_attribute][0])
             return None
 
-    def get_principal(self, principal_id, info=True):
+    def get_principal(self, principal_id, info=True):  # pylint: disable=too-many-return-statements,too-many-branches
         """Get principal for given ID"""
         if not self.enabled:
             return None
@@ -379,15 +381,17 @@ class LDAPPlugin(Persistent, Contained):
             return None
         user_dn, attrs = result[0]
         if info:
-            return PrincipalInfo(id=LOGIN_PREFIX.format(prefix=self.prefix,
-                                                        login=login),
+            return PrincipalInfo(id=PRINCIPAL_ID_FORMATTER.format(prefix=self.prefix,
+                                                                  login=login),
                                  title=self.title_format.format(**attrs),
                                  dn=user_dn)
-        attrs.update({'principal_id': LOGIN_PREFIX.format(
-            prefix=self.prefix, login=login)})
+        attrs.update({
+            'principal_id': PRINCIPAL_ID_FORMATTER.format(prefix=self.prefix,
+                                                          login=login)
+        })
         return LDAPUserInfo(user_dn, attrs, self)
 
-    def _get_groups(self, principal):
+    def _get_groups(self, principal):  # pylint: disable=too-many-branches
         """Get principal groups"""
         principal_dn = principal.attributes.get(DN_ATTRIBUTE)
         if principal_dn is None:
@@ -447,7 +451,7 @@ class LDAPPlugin(Persistent, Contained):
             return result
         return set()
 
-    def get_members(self, group, info=True):
+    def get_members(self, group, info=True):  # pylint: disable=too-many-branches
         """Get all members of given LDAP group as LDAP users"""
         if not self.enabled:
             return
@@ -481,9 +485,8 @@ class LDAPPlugin(Persistent, Contained):
             for user_dn, user_attrs in search.execute(conn, group_dn=group.dn):
                 if info:
                     if self.uid_attribute == DN_ATTRIBUTE:
-                        yield PrincipalInfo(id=USER_DN_PREFIX.format(
-                            prefix=self.prefix,
-                            dn=user_dn),
+                        yield PrincipalInfo(id=USER_DN_PREFIX.format(prefix=self.prefix,
+                                                                     dn=user_dn),
                                             title=self.title_format.format(**user_attrs),
                                             dn=user_dn)
                     else:
@@ -529,10 +532,9 @@ class LDAPPlugin(Persistent, Contained):
                                self.groups_search_scope, attributes)
             for group_dn, group_attrs in search.execute(conn, query=query):
                 if self.group_uid_attribute == DN_ATTRIBUTE:
-                    yield PrincipalInfo(id=GROUP_DN_PREFIX.format(
-                        prefix=self.prefix,
-                        group_prefix=self.group_prefix,
-                        dn=group_dn),
+                    yield PrincipalInfo(id=GROUP_DN_PREFIX.format(prefix=self.prefix,
+                                                                  group_prefix=self.group_prefix,
+                                                                  dn=group_dn),
                                         title=self.group_title_format.format(**group_attrs),
                                         dn=group_dn)
                 else:
